// A helper function used to read a Node.js readable stream into a string
async function streamToString(readableStream) {
  return new Promise((resolve, reject) => {
    const chunks = [];
    readableStream.on("data", (data) => {
      chunks.push(data.toString());
    });
    readableStream.on("end", () => {
      resolve(chunks.join(""));
    });
    readableStream.on("error", reject);
  });
}

const { BlobServiceClient } = require("@azure/storage-blob");
const CONNECTION = process.env.AZURE_STORAGE_CONNECTION_STRING;
const blobServiceClient = BlobServiceClient.fromConnectionString(CONNECTION);
const containerClient = blobServiceClient.getContainerClient("test");
(async () => {
  for await (const blob of containerClient.listBlobsFlat()) {
    console.log("\t", blob.name);
    const blobClient = containerClient.getBlockBlobClient(blob.name);
    const downloadBlockBlobResponse = await blobClient.download(0);
    console.log("\nDownloaded blob content...");
    console.log(
      "\t",
      await streamToString(downloadBlockBlobResponse.readableStreamBody)
    );
  }
})();
