import os
from azure.ai.anomalydetector import AnomalyDetectorClient
from azure.ai.anomalydetector.models import DetectRequest, TimeSeriesPoint, TimeGranularity
from azure.core.credentials import AzureKeyCredential
import pandas as pd
import matplotlib.pyplot as plt

SUBSCRIPTION_KEY = os.environ["ANOMALY_DETECTOR_KEY"]
ANOMALY_DETECTOR_ENDPOINT = os.environ["ANOMALY_DETECTOR_ENDPOINT"]
TIME_SERIES_DATA_PATH = os.path.join("data", "request-data.csv")

client = AnomalyDetectorClient(AzureKeyCredential(SUBSCRIPTION_KEY),
                               ANOMALY_DETECTOR_ENDPOINT)

series = []
df = pd.read_csv(TIME_SERIES_DATA_PATH,
                 header=None, encoding='utf-8', parse_dates=[0])
# df.index = pd.to_datetime(df[0])
# df = df.drop(0, axis=1)
# df.plot(x_compat=True)
# plt.show()

for index, row in df.iterrows():
    series.append(TimeSeriesPoint(
        timestamp=row[0].to_pydatetime(), value=row[1]))

request = DetectRequest(series=series, granularity=TimeGranularity.daily)

print('Detecting anomalies in the entire time series.')

try:
    response = client.detect_entire_series(request)
except Exception as e:
    print(e)

if any(response.is_anomaly):
    print('An anomaly was detected at index:')
    print([i for i, value in enumerate(response.is_anomaly) if value])
else:
    print('No anomalies were detected in the time series.')

print('Detecting the anomaly status of the latest data point.')

try:
    response = client.detect_last_point(request)
except Exception as e:
    print(e)

if response.is_anomaly:
    print('The latest point is detected as anomaly.')
else:
    print('The latest point is not detected as anomaly.')
