const os = require("os");
const fs = require("fs");
const path = require("path");
const https = require("https");

const functions = require("firebase-functions");
const admin = require("firebase-admin");
admin.initializeApp();

exports.uploadimage = functions.region("asia-northeast1").storage
  .object()
  .onFinalize(async (obj) => {

    const contentType = obj.contentType;
    const filePath = obj.name;
    const fileName = path.basename(filePath);
    const fileBucket = obj.bucket;

    if (!contentType.startsWith("image/")) {
      return functions.logger.log("This is not an image.");
    }
    const bucket = admin.storage().bucket(fileBucket);
    const tempFilePath = path.join(os.tmpdir(), fileName);

    await bucket
      .file(filePath)
      .download({ destination: tempFilePath, validation: false });
    functions.logger.log("Image downloaded locally to", tempFilePath);
    const r = await analyzeImage(tempFilePath);
    const rObj = JSON.parse(r)
    await admin.firestore().collection("images").add({
      path: filePath,
      tags: rObj.tags
    });
  });


async function analyzeImage(file) {
  const data = fs.readFileSync(file);
  const url =
    "https://japaneast.api.cognitive.microsoft.com/vision/v3.2/analyze?" +
    "visualFeatures=Categories,Tags&language=ja";
  const options = {
    method: "POST",
    headers: {
      "Content-Type": "application/octet-stream",
      "Ocp-Apim-Subscription-Key": "58dd3428a9254e66baf95ccccea4d953",
    },
  };

  return new Promise((resolve, reject) => {
    let req = https.request(url, options, (res) => {
      res.on("data", (chunk) => {
        resolve("" + chunk);
      });
    });
    req.on("error", (e) => {
      reject(e.message);
    });
    req.write(data);
    req.end();
  });
}
