import { shallowMount, mount } from "@vue/test-utils";
import App from "@/App.vue";
import InventoryInput from "@/components/InventoryInput.vue";
import InventoryChart from "@/components/InventoryChart.vue";
import InventoryHistory from "@/components/InventoryHistory.vue";

describe("App.vue component", () => {
  let wrapper;
  beforeEach(() => {
    wrapper = shallowMount(App);
  });

  it("test1) add event", () => {
    const data = { model: "A", count: "3" };
    wrapper.vm.add(data);
    expect(wrapper.vm.inventory[0].model).toEqual("A");
    expect(wrapper.vm.inventory[0].add).toEqual(3);
  });

  it("test2) del event", () => {
    const data = { model: "B", count: "2" };
    wrapper.vm.del(data);
    expect(wrapper.vm.inventory[0].model).toEqual("B");
    expect(wrapper.vm.inventory[0].del).toEqual(2);
  });

  it("test3) add & del event", () => {
    wrapper.setData({ models: ["A", "B", "C"] });
    wrapper.vm.add({ model: "A", count: "5" });
    wrapper.vm.del({ model: "A", count: "2" });
    wrapper.vm.add({ model: "B", count: "5" });
    wrapper.vm.add({ model: "B", count: "2" });
    expect(wrapper.vm.chartdata[0]).toBe(3);
    expect(wrapper.vm.chartdata[1]).toBe(7);
  });
});

describe("App.vue with components", () => {
  let wrapper;
  
  beforeEach(() => {
    wrapper = mount(App);
    wrapper.setData({ models: ["A", "B", "C"] });
  });

  it("scenario1", async () => {
    // input data via InventoryInput component
    const input = wrapper.findComponent(InventoryInput);
    input.find("select").setValue("A");
    input.find("[type='range']").setValue(30);
    await wrapper.vm.$nextTick();
    
    input.find("#addButton").trigger("click");
    await wrapper.vm.$nextTick();

    input.find("[type='range']").setValue(15);
    input.find("#delButton").trigger("click");
    await wrapper.vm.$nextTick();
    
    // check the model updated properly
    const inventory = wrapper.vm.inventory;
    expect(inventory[0].model).toMatch("A")
    expect(inventory[0].add).toBe(30)
    expect(inventory[0].del).toBe(0)
    expect(inventory[1].model).toMatch("A")
    expect(inventory[1].add).toBe(0)
    expect(inventory[1].del).toBe(15)

    // chart displayed properly?
    const chart = wrapper.findComponent(InventoryChart);
    const col2 = chart.findAll("div.col-2");
    expect(col2[0].text()).toMatch("A");
    const bars = chart.findAll("div.bar");
    expect(bars[0].attributes("style")).toMatch("width: 150px;");

    // history displayed properly?
    const history = wrapper.findComponent(InventoryHistory);
    const trs = history.findAll("tr");
    expect(trs[1].text()).toEqual("A300")
    expect(trs[2].text()).toEqual("A015")
  });
});
