import { shallowMount } from "@vue/test-utils";
import InventoryInput from "@/components/InventoryInput.vue";

describe("InventoryInput.vue", () => {
  let wrapper;
  beforeEach(() => {
    wrapper = shallowMount(InventoryInput, {
      props: { models: ["A", "B", "C"] },
    });
  });

  it("1) list up options are created with models property", () => {
    const options = wrapper.findAll("option");
    expect(options.length).toBe(3);
    expect(options[0].text()).toMatch("A");
    expect(options[1].text()).toMatch("B");
    expect(options[2].text()).toMatch("C");
  });

  it("2) is not possible to click unless an option is selected", async () => {
    const addButton = wrapper.find("#addButton")
    const delButton = wrapper.find("#delButton")
    
    expect(addButton.classes()).toContain("disabled")
    expect(delButton.classes()).toContain("disabled")

    addButton.trigger("click")
    delButton.trigger("click")

    await wrapper.vm.$nextTick()
    expect(wrapper.emitted("add")).toBeUndefined()
    expect(wrapper.emitted("del")).toBeUndefined()
  });

  it("3) is possible to click if an option is selected", async () => {
    const addButton = wrapper.find("#addButton")
    const delButton = wrapper.find("#delButton")
    wrapper.setData({model:"A", count:3})
    await wrapper.vm.$nextTick()

    expect(addButton.classes()).not.toContain("disabled")
    expect(delButton.classes()).not.toContain("disabled")
    addButton.trigger("click")
    delButton.trigger("click")
    
    await wrapper.vm.$nextTick()
    expect(wrapper.emitted("add")[0]).toEqual([{"count": 3, "model": "A"}]);
    expect(wrapper.emitted("del")[0]).toEqual([{"count": 3, "model": "A"}]);
  });

  it("4) model is updated if you select an option", async () => {
    wrapper.findAll('option').at(1).setSelected()
    // wrapper.find('select').setValue("B")
    await wrapper.vm.$nextTick()
    expect(wrapper.vm.model).toBe("B")
  })

  it("5) count is updated if you move the slider", async () => {
    wrapper.find('[type="range"]').setValue(55)
    await wrapper.vm.$nextTick()
    expect(wrapper.vm.count).toBe("55")
  })
});
