import { shallowMount } from "@vue/test-utils";
import App from "@/App.vue";

import { initializeApp } from "firebase/app";
import { getFirestore, onSnapshot, collection } from "firebase/firestore";
import { getStorage, getDownloadURL, ref, uploadBytes } from "firebase/storage";

const mockData = [
  {
    data() {
      return {
        path: "img1.jpg",
        tags: [{ name: "空" }, { name: "海" }],
      };
    },
  },
  {
    data() {
      return {
        path: "img2.jpg",
        tags: [{ name: "人" }, { name: "建物" }],
      };
    },
  },
];

jest.mock("firebase/app", () => {
  return {
    initializeApp: jest.fn(() => {
      return () => {};
    }),
  };
});

jest.mock("firebase/firestore", () => {
  return {
    getFirestore: jest.fn(() => {
      return () => {};
    }),
    onSnapshot: jest.fn((ref, callback) => {
      callback(mockData);
    }),
    collection: jest.fn((db, col) => {
      return "imgRefMock";
    }),
  };
});

jest.mock("firebase/storage", () => {
  return {
    getStorage: jest.fn(() => {
      return () => {};
    }),
    getDownloadURL: jest.fn((ref) => {
      return "https://hoge.com/" + ref[1];
    }),
    ref: jest.fn((str, path) => {
      return [str, path];
    }),
    uploadBytes: jest.fn((ref, file)=>{}),
  };
});

Object.defineProperty(global.document, 'querySelector', { value: jest.fn(
  () => {
    return {
      files: ["newimage.jpg"]
    }
  }
) });

describe("App.vue", () => {
  it("test1) images/tags are properly displayed", async () => {
    const wrapper = shallowMount(App);
    await wrapper.vm.$nextTick();

    const data = wrapper.vm.images;
    expect(data[0].url).toMatch("https://hoge.com/img1.jpg");
    expect(data[1].url).toMatch("https://hoge.com/img2.jpg");

    const imgs = wrapper.findAll("img");
    expect(imgs[0].attributes("src")).toMatch("https://hoge.com/img1.jpg");
    expect(imgs[1].attributes("src")).toMatch("https://hoge.com/img2.jpg");

    const tags = wrapper.findAll(".col-9");
    expect(JSON.parse(tags[0].text())).toEqual(["空", "海"]);
    expect(JSON.parse(tags[1].text())).toEqual(["人", "建物"]);
  });

  it("test2) an image is uploaded", async () => {
    const wrapper = shallowMount(App);
    const file = wrapper.find("#formFile");

    file.trigger("change");
    await wrapper.vm.$nextTick();
    expect(uploadBytes.mock.calls[0][1]).toBe('newimage.jpg')
  });
});
