import { expect } from "chai";
import { setDoc, doc } from "firebase/firestore";
import { shallowMount } from "@vue/test-utils";
import { initializeTestEnvironment } from "@firebase/rules-unit-testing";
import { stub } from "sinon";
import App from "@/App.vue";
import * as mystub from "@/mystub";

describe("Frontend & Firestore", () => {
  let mockDB;
  let uploadStub;

  before(async () => {
    const testEnv = await initializeTestEnvironment({
      projectId: "demo-project-1234",
      firestore: {
        // rules: readFileSync("firestore.rules", "utf8"),
        host: "localhost",
        port: 8080,
      },
    });
    const ctx = await testEnv.authenticatedContext("Taro");
    mockDB = ctx.firestore();

    stub(mystub, "stubGetFirestore").returns(mockDB);
    stub(mystub, "stubGetDownloadUrl").callsFake(function (a) {
      return `https://hoge.com/${a.fullPath}`;
    });
    uploadStub = stub(mystub, "stubUploadBytes");

    Object.defineProperty(global.document, "querySelector", {
      value: stub(() => {
        return {
          files: ["newimage.jpg"],
        };
      }),
    });
  });

  beforeEach(async () => {
    await setDoc(doc(mockDB, "images", "img1"), {
      path: "image1.jpg",
      tags: [{ name: "人" }],
    });
    await setDoc(doc(mockDB, "images", "img2"), {
      path: "image2.jpg",
      tags: [{ name: "海" }, { name: "建物" }],
    });
  });

  it("create App", (done) => {
    const wrapper = shallowMount(App);
    setTimeout(() => {
      const data = wrapper.vm.images;
      expect(data[0].url).to.equal("https://hoge.com/image1.jpg");
      expect(data[1].url).to.equal("https://hoge.com/image2.jpg");

      const imgs = wrapper.findAll("img");
      expect(imgs[0].attributes("src")).to.equal("https://hoge.com/image1.jpg");
      expect(imgs[1].attributes("src")).to.equal("https://hoge.com/image2.jpg");

      const tags = wrapper.findAll(".col-9");
      expect(JSON.parse(tags[0].text())).to.eql(["人"]);
      expect(JSON.parse(tags[1].text())).to.eql(["海", "建物"]);
      done();
    }, 1000);
  });

  it("an image is uploaded", async () => {
    const wrapper = shallowMount(App);
    const file = wrapper.find("#formFile");

    file.trigger("change");
    await wrapper.vm.$nextTick();
    expect(uploadStub.getCall(0).args[1]).to.equal("newimage.jpg");
  });
});
