const admin = require("firebase-admin");
const projectId = "fir-functions-test-5385a";
const test = require("firebase-functions-test")({
  projectId: projectId,
}, "./serviceAccountKey.json");

const myFunctions = require("../index");

describe("firebase-functions-test", () => {
  it("tests a simple HTTP function", async () => {
    // A fake request object, with req.query.text set to 'input'
    const req = { query: { text: "input" } };

    const sendPromise = new Promise((resolve) => {
      // A fake response object, with a stubbed send() function which asserts that it is called
      // with the right result
      const res = {
        send: (text) => {
          resolve(text);
        },
      };

      // Invoke function with our fake request and response objects.
      myFunctions.simpleHttp(req, res);
    });

    // Wait for the promise to be resolved and then check the sent text
    const text = await sendPromise;
    expect(text).toMatch(`text: input`);
  });

  it("tests a Cloud Firestore function", async () => {
    const wrapped = test.wrap(myFunctions.firestoreUppercase);

    // Make a fake document snapshot to pass to the function
    const after = test.firestore.makeDocumentSnapshot(
      {
        text: "hello world",
      },
      "/lowercase/foo"
    );
    // Call the function
    await wrapped(after);

    // Check the data in the Firestore emulator
    const snap = await admin.firestore().doc("/uppercase/foo").get();
    expect(snap.data()).toEqual({
      text: "HELLO WORLD",
    });
  });
});
